﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using Caliburn.Micro;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Controls;
using System.Xml.Linq;
using System.Diagnostics;
using System.Xml;
using System.IO;
using System.ComponentModel;

namespace RibbonApplication.Models
{

   class Ribbon
   {
      public static ObservableCollection<CustomRibbonTab> ParseXMLRun(string ribbon_file_path)
      {

         XmlDocument doc = new XmlDocument();
         string currentDir = Environment.CurrentDirectory;
         doc.Load(Path.GetFullPath(Path.Combine(currentDir, @"..\..\" + ribbon_file_path)));
         //doc.Load(@"..\VistaNextGenK\build\wpfuserinterfaces\LtgsRibbon\ribboncontents.xml");

         XNamespace nonamespace = XNamespace.None;

         XmlNodeList result = doc.SelectNodes("//tab");

         

         ObservableCollection<CustomRibbonTab> tabs = new ObservableCollection<CustomRibbonTab>();
        

         for (int i = 0; i < result.Count; i++)
         {
            string atts = result.Item(i).Attributes["name"].Value;
            
            XmlNodeList barNodes = result.Item(i).ChildNodes;
            ObservableCollection<CustomRibbonBar> bars = new ObservableCollection<CustomRibbonBar>();
            for(int j=0; j<barNodes.Count; j++)
            {
               string barAtts = barNodes.Item(j).Attributes["name"].Value;

               XmlNodeList itemNodes = barNodes.Item(j).ChildNodes;
               ObservableCollection<CustomRibbonItem> items = new ObservableCollection<CustomRibbonItem>();
               for (int k=0; k<itemNodes.Count; k++)
               {
                  string itemAtts = itemNodes.Item(k).Attributes["name"].Value;
                  if (itemNodes.Item(k).HasChildNodes)
                  {
                     XmlNodeList specsNodes = itemNodes.Item(k).ChildNodes;
                     bool islarge = false;
                     string image = "";
                     string splitbutton = "";
                     string tooltip = "";
                     bool isenabled = true;
                     ObservableCollection<CustomRibbonDropDown> dropdowns = new ObservableCollection<CustomRibbonDropDown>();

                     string islargestr = specsNodes.Item(0).Attributes["bool"].Value;
                     if (islargestr.Equals("true"))
                     {
                        islarge = true;
                     }
                     image = specsNodes.Item(1).Attributes["location"].Value;
                     splitbutton = specsNodes.Item(2).Attributes["type"].Value;
                     tooltip = specsNodes.Item(3).Attributes["content"].Value;
                     string isenabledstr = specsNodes.Item(4).Attributes["enabled"].Value;
                     if (isenabledstr.Equals("false"))
                     {
                        isenabled = false;
                     }
                     if (specsNodes.Item(2).HasChildNodes)
                     {
                        XmlNodeList dropdownNodes = specsNodes.Item(2).ChildNodes;
                        for (int n = 0; n < dropdownNodes.Count; n++)
                        {
                           string dropdownName = dropdownNodes.Item(n).Attributes["name"].Value;
                           CustomRibbonDropDown dropdown = new CustomRibbonDropDown { DropDownHeader = dropdownName };
                           dropdowns.Add(dropdown);
                        }
                     }
                     CustomRibbonItem item = new CustomRibbonItem { ItemHeader = itemAtts, IsLarge = islarge, Image = image, IsSplitButton=splitbutton, CustomRibbonDropDowns =  dropdowns, ToolTip=tooltip, IsEnabled = isenabled };
                     items.Add(item);
                    }
                  else
                  {
                     CustomRibbonItem item = new CustomRibbonItem { ItemHeader = itemAtts};
                     items.Add(item);
                  }
                  
                  
               }
               CustomRibbonBar bar = new CustomRibbonBar { BarHeader = barAtts, CustomRibbonItems = items };
               bars.Add(bar);
            }
            CustomRibbonTab tab = new CustomRibbonTab { TabHeader = atts, CustomRibbonBars = bars };
            tabs.Add(tab);
         }
         return tabs;
      }

      public class CustomRibbonTab
      {
         public string TabHeader { get; set; }
         public ObservableCollection<CustomRibbonBar> CustomRibbonBars { get; set; }
         public CustomRibbonTab()
         {
            CustomRibbonBars = new ObservableCollection<CustomRibbonBar>();
         }
      }


      public class CustomRibbonBar
      {
         public string BarHeader { get; set; }

         public ObservableCollection<CustomRibbonItem> CustomRibbonItems
         {
            get; set;
         }
         public CustomRibbonBar()
         {
            CustomRibbonItems = new ObservableCollection<CustomRibbonItem>();
         }
      }
      public class CustomRibbonItem :INotifyPropertyChanged
      {

         public ObservableCollection<CustomRibbonDropDown> CustomRibbonDropDowns
         {
            get; set;
         }
         public CustomRibbonItem()
         {
            IsSplitButton = "";
            IsBoolean = true;
            ToolTip = "";

            CustomRibbonDropDowns = new ObservableCollection<CustomRibbonDropDown>();
         }
         public string ItemHeader
         {
            get;
            set;
         }
         public string Image { get; set; }
         public bool IsBoolean { get; set; }
         public bool IsLarge { get; set; }
         public string IsSplitButton { get; set; }
         public string ToolTip { get; set; }

         private bool isEnabled = true;
         public bool IsEnabled
            {
                get
                {
                    return isEnabled;
                }
                set
                {
                    isEnabled = value;
                    OnPropertyChanged("IsEnabled");
                }
            }


            public event PropertyChangedEventHandler PropertyChanged;

            public void OnPropertyChanged(string name)
            {
                if (PropertyChanged != null)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs(name));
                }
            }


            // public bool separator { get; set; }

        }
                      


      public class CustomRibbonDropDown
      {

         public CustomRibbonDropDown()
         {

         }
         public string DropDownHeader
         {
            get;
            set;
         }


      }

   }
   
}



   

   
